@@ -355,4 +355,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
-RegionName = Literal["us-east-1"]
+RegionName = Literal["eu-central-1", "us-east-1"]
